Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Configure ¶
func Configure(params ConfigureParams) error
Configure connects to the specified host over SSH, and executes a script that carries out cloud-config.
func ConfigureScript ¶
ConfigureScript generates the bash script that applies the specified cloud-config.
func RunConfigureScript ¶
func RunConfigureScript(script string, params ConfigureParams) error
RunConfigureScript connects to the specified host over SSH, and executes the provided script which is expected to have been returned by ConfigureScript.
Types ¶
type ConfigureParams ¶
type ConfigureParams struct {
// Host is the host to configure, in the format [user@]hostname.
Host string
// Client is the SSH client to connect with.
// If Client is nil, ssh.DefaultClient will be used.
Client ssh.Client
// Config is the cloudinit config to carry out.
Config *cloudinit.Config
// ProgressWriter is an io.Writer to which progress will be written,
// for realtime feedback.
ProgressWriter io.Writer
}
Click to show internal directories.
Click to hide internal directories.